@@ -95,6 +95,9 @@ sort_ints (GtkTreeModel *model, GtkTreeIter *itera, GtkTreeIter *iterb, gpointer
 	case COL_CPU:
 		return PROCMAN_RCMP(infoa->pcpu, infob->pcpu);
 
+	case COL_MEM:
+		return PROCMAN_RCMP(infoa->mem, infob->mem);
+
 	default:
 		g_assert_not_reached();
 		return 0;
@@ -103,6 +106,32 @@ sort_ints (GtkTreeModel *model, GtkTreeIter *itera, GtkTreeIter *iterb, gpointer
 
 
 
+static GtkWidget *
+create_proctree(GtkTreeModel *model)
+{
+	GtkWidget *proctree;
+	GtkWidget* (*new)(void);
+	void (*set_column)(void*, guint);
+
+
+	if (load_symbols("libsexy.so",
+			 "sexy_tree_view_new", &new,
+			 "sexy_tree_view_set_tooltip_label_column", &set_column,
+			 NULL)) {
+		proctree = new();
+		gtk_tree_view_set_model(GTK_TREE_VIEW(proctree), model);
+		set_column(proctree, COL_TOOLTIP);
+	} else {
+		proctree = gtk_tree_view_new_with_model(model);
+	}
+
+	return proctree;
+}
+
+
+
+
+
 static void
 set_proctree_reorderable(ProcData *procdata)
 {
@@ -241,7 +270,7 @@ proctable_new (ProcData * const procdata)
 	GtkTreeViewColumn *column;
 	GtkCellRenderer *cell_renderer;
 
-	static const gchar *titles[] = {
+	const gchar *titles[] = {
 		N_("Process Name"),
 		N_("User"),
 		N_("Status"),
@@ -257,13 +286,14 @@ proctable_new (ProcData * const procdata)
 		N_("ID"),
 		N_("Security Context"),
 		N_("Arguments"),
+		N_("Memory"),
 		NULL,
 		"POINTER"
 	};
 
-	gint i;
+	g_assert(COL_MEM == 15);
 
-	PROCMAN_GETTEXT_ARRAY_INIT(titles);
+	gint i;
 
 	scrolled = gtk_scrolled_window_new (NULL, NULL);
 	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolled),
@@ -286,11 +316,13 @@ proctable_new (ProcData * const procdata)
 				    G_TYPE_UINT,	/* ID		*/
 				    G_TYPE_STRING,	/* Security Context */
 				    G_TYPE_STRING,	/* Arguments	*/
+				    G_TYPE_STRING,	/* Memory       */
 				    GDK_TYPE_PIXBUF,	/* Icon		*/
-				    G_TYPE_POINTER	/* ProcInfo	*/
+				    G_TYPE_POINTER,	/* ProcInfo	*/
+				    G_TYPE_STRING	/* Sexy tooltip */
 		);
 
-	proctree = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
+	proctree = create_proctree(GTK_TREE_MODEL(model));
 	gtk_tree_view_set_search_equal_func (GTK_TREE_VIEW (proctree),
 					     search_equal_func,
 					     NULL,
@@ -314,15 +346,16 @@ proctable_new (ProcData * const procdata)
 	gtk_tree_view_column_set_attributes (column, cell_renderer,
 					     "text", COL_NAME,
 					     NULL);
-	gtk_tree_view_column_set_title (column, titles[0]);
+	gtk_tree_view_column_set_title (column, _(titles[0]));
 	gtk_tree_view_column_set_sort_column_id (column, COL_NAME);
 	gtk_tree_view_column_set_resizable (column, TRUE);
+	gtk_tree_view_column_set_sizing(column, GTK_TREE_VIEW_COLUMN_FIXED);
 	gtk_tree_view_column_set_min_width (column, 1);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (proctree), column);
 	gtk_tree_view_set_expander_column (GTK_TREE_VIEW (proctree), column);
 
 
-	for (i = COL_USER; i <= COL_ARGS; i++) {
+	for (i = COL_USER; i <= COL_MEM; i++) {
 		cell_renderer = gtk_cell_renderer_text_new ();
 
 		switch(i)
@@ -336,6 +369,7 @@ proctable_new (ProcData * const procdata)
 		case COL_NICE:
 		case COL_PID:
 		case COL_CPU_TIME:
+		case COL_MEM:
 			g_object_set(G_OBJECT(cell_renderer),
 				     "xalign", 1.0f,
 				     NULL);
@@ -346,9 +380,16 @@ proctable_new (ProcData * const procdata)
 		gtk_tree_view_column_set_attributes (column, cell_renderer,
 						     "text", i,
 						     NULL);
-		gtk_tree_view_column_set_title (column, titles[i]);
+		gtk_tree_view_column_set_title (column, _(titles[i]));
 		gtk_tree_view_column_set_sort_column_id (column, i);
 		gtk_tree_view_column_set_resizable (column, TRUE);
+
+		switch (i) {
+		case COL_ARGS:
+			gtk_tree_view_column_set_sizing(column, GTK_TREE_VIEW_COLUMN_FIXED);
+			break;
+		}
+
 		gtk_tree_view_column_set_min_width (column, 1);
 		gtk_tree_view_append_column (GTK_TREE_VIEW (proctree), column);
 	}
@@ -356,7 +397,7 @@ proctable_new (ProcData * const procdata)
 	gtk_container_add (GTK_CONTAINER (scrolled), proctree);
 
 
-	for(i = COL_NAME; i <= COL_ARGS; i++)
+	for(i = COL_NAME; i <= COL_MEM; i++)
 	{
 		switch(i)
 		{
@@ -368,6 +409,7 @@ proctable_new (ProcData * const procdata)
 		case COL_CPU_TIME:
 		case COL_START_TIME:
 		case COL_CPU:
+		case COL_MEM:
 			gtk_tree_sortable_set_sort_func (
 				GTK_TREE_SORTABLE (model),
 				i,
@@ -415,6 +457,7 @@ proctable_free_info(ProcInfo *info)
 	}
 
 	g_free (info->name);
+	g_free(info->tooltip);
 	g_free (info->arguments);
 	g_free (info->security_context);
 	g_slist_free (info->children);
@@ -547,6 +590,8 @@ get_process_memory_info(ProcInfo *info)
 	info->memxserver = xresources.total_bytes_estimate;
 
 	get_process_memory_writable(info);
+
+	info->mem = info->memxserver + info->memwritable;
 }
 
 
@@ -598,13 +643,14 @@ static void
 update_info_mutable_cols(GtkTreeStore *store, ProcData *procdata, ProcInfo *info)
 {
 	gchar *vmsize, *memres, *memwritable, *memshared, *memxserver,
-		*cpu_time, *start_time;
+		*cpu_time, *start_time, *mem;
 
 	vmsize	   = SI_gnome_vfs_format_file_size_for_display (info->vmsize);
 	memres	   = SI_gnome_vfs_format_file_size_for_display (info->memres);
 	memwritable = SI_gnome_vfs_format_file_size_for_display (info->memwritable);
 	memshared  = SI_gnome_vfs_format_file_size_for_display (info->memshared);
 	memxserver = SI_gnome_vfs_format_file_size_for_display (info->memxserver);
+	mem = SI_gnome_vfs_format_file_size_for_display(info->mem);
 
 	cpu_time = format_duration_for_display (info->cpu_time_last / procdata->frequency);
 
@@ -624,6 +670,7 @@ update_info_mutable_cols(GtkTreeStore *store, ProcData *procdata, ProcInfo *info
 			    COL_CPU_TIME, cpu_time,
 			    COL_START_TIME, start_time,
 			    COL_NICE, info->nice,
+			    COL_MEM, mem,
 			    -1);
 
 	/* FIXME: We don't bother updating COL_SECURITYCONTEXT as it can never change.
@@ -635,6 +682,7 @@ update_info_mutable_cols(GtkTreeStore *store, ProcData *procdata, ProcInfo *info
 	g_free (memxserver);
 	g_free (cpu_time);
 	g_free(start_time);
+	g_free(mem);
 }
 
 
@@ -682,6 +730,7 @@ insert_info_to_tree (ProcInfo *info, ProcData *procdata)
 			    COL_PIXBUF, info->pixbuf,
 			    COL_NAME, info->name,
 			    COL_ARGS, info->arguments,
+			    COL_TOOLTIP, info->tooltip,
 			    COL_PID, info->pid,
 			    COL_SECURITYCONTEXT, info->security_context,
 			    -1);
@@ -840,7 +889,8 @@ procinfo_new (ProcData *procdata, gint pid)
 	get_process_name (info, procstate.cmd, arguments[0]);
 	get_process_user (procdata, info, procstate.uid);
 
-	info->arguments = g_strjoinv(" ", arguments);
+	info->tooltip = g_strjoinv(" ", arguments);
+	info->arguments = g_strescape(info->tooltip, "\\\"");
 	g_strfreev(arguments);
 
 	info->pcpu = 0;
